#
# spec file for package perl-Email-Abstract
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Email-Abstract
Name:           perl-Email-Abstract
Version:        3.10.0
Release:        2.2
%define cpan_version 3.010
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Unified interface to mail representations
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/R/RJ/RJBS/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Email::Simple) >= 1.998
BuildRequires:  perl(ExtUtils::MakeMaker) >= 6.78
BuildRequires:  perl(MRO::Compat)
BuildRequires:  perl(Module::Pluggable) >= 1.5
BuildRequires:  perl(Test::More) >= 0.96
Requires:       perl(Email::Simple) >= 1.998
Requires:       perl(MRO::Compat)
Requires:       perl(Module::Pluggable) >= 1.5
Provides:       perl(Email::Abstract) = 3.10.0
Provides:       perl(Email::Abstract::EmailMIME) = 3.10.0
Provides:       perl(Email::Abstract::EmailSimple) = 3.10.0
Provides:       perl(Email::Abstract::MIMEEntity) = 3.10.0
Provides:       perl(Email::Abstract::MailInternet) = 3.10.0
Provides:       perl(Email::Abstract::MailMessage) = 3.10.0
Provides:       perl(Email::Abstract::Plugin) = 3.10.0
%undefine       __perllib_provides
%{perl_requires}

%description
'Email::Abstract' provides module writers with the ability to write simple,
representation-independent mail handling code. For instance, in the cases
of 'Mail::Thread' or 'Mail::ListDetector', a key part of the code involves
reading the headers from a mail object. Where previously one would either
have to specify the mail class required, or to build a new object from
scratch, 'Email::Abstract' can be used to perform certain simple operations
on an object regardless of its underlying representation.

'Email::Abstract' currently supports 'Mail::Internet', 'MIME::Entity',
'Mail::Message', 'Email::Simple', 'Email::MIME', and 'Courriel'. Other
representations are encouraged to create their own 'Email::Abstract::*'
class by copying 'Email::Abstract::EmailSimple'. All modules installed
under the 'Email::Abstract' hierarchy will be automatically picked up and
used.

%prep
%autosetup  -n %{cpan_name}-%{cpan_version}

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes README
%license LICENSE

%changelog
* Fri Mar  8 2024 Tina Müller <tina.mueller@suse.com>
- Fix disabling of __perllib_provides
* Tue Sep  5 2023 Tina Müller <timueller+perl@suse.de>
- updated to 3.010
  see /usr/share/doc/packages/perl-Email-Abstract/Changes
  3.010     2023-09-02 20:22:12-04:00 America/New_York
  - update packaging metadata
* Mon Jun 21 2021 Tina Müller <timueller+perl@suse.de>
- updated to 3.009
  see /usr/share/doc/packages/perl-Email-Abstract/Changes
  3.009     2021-06-20 16:54:40-04:00 America/New_York
  - MIME::Entity 5.508 is required for operation
  - update author information
  - add a perl support section to docs
* Tue Apr 14 2015 coolo@suse.com
- updated to 3.008
  see /usr/share/doc/packages/perl-Email-Abstract/Changes
  3.008     2014-12-27 18:36:19-05:00 America/New_York
  - make results of get_body be the same on Email::{Simple,MIME}
  - ...but this method is a mess, so maybe avoid using Abstract for body
    work
  3.007     2013-12-31 10:39:14 America/New_York
    fix skip count when MIME::Entity is not present
  3.006     2013-09-01 08:41:48 America/New_York
    require Email::Simple 1.998 to allow ->new(\$string)
  3.005     2013-07-30 09:57:36 America/New_York
    repackage, update bug tracker, etc.
    provide raw body on multipart Email::MIME messages (thanks,
    bailey@upenn)
    [rt.cpan.org #77624]
* Tue May 31 2011 coolo@novell.com
- updated to 3.004
    If present, MIME::Entity must be v5.501; v5.500 had a regression (or
    a bug fix, depending how you look at it) that broke header-reading.
    While technically older versions that are not 5.500 would work, it is
    much simpler to just require the newest version, rather than to
    support a version range with a hole in it.
    replace Class::ISA with mro (MRO::Compat)
    avoid a warning in MailInternet with zero headers found
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Nov 29 2010 coolo@novell.com
- remove /var/adm/perl-modules
* Tue Jun  2 2009 lars@linux-schulserver.de
- update to 3.001
* Thu Sep 13 2007 James Oakley <jfunk@funktronics.ca> - 2.132-1
- Initial release
